Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3233)

Unified Diff: chrome/test/automation/automation_proxy_uitest.h

Issue 5707006: Revert "Add named testing interface." (Closed)
Patch Set: Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/automation/automation_proxy.cc ('k') | chrome/test/automation/automation_proxy_uitest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/automation/automation_proxy_uitest.h
diff --git a/chrome/test/automation/automation_proxy_uitest.h b/chrome/test/automation/automation_proxy_uitest.h
index 4e6d09563359280187ecfaa5baa235d591349350..55da8cc8ee0b3ed7bc4268c403faab24b594f3c4 100644
--- a/chrome/test/automation/automation_proxy_uitest.h
+++ b/chrome/test/automation/automation_proxy_uitest.h
@@ -112,17 +112,16 @@ class ExternalTabUITestMockClient : public AutomationProxy {
class ExternalTabUITest : public UITest {
public:
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {}
// Override UITest's CreateProxyLauncher to provide the unit test
// with our special implementation of AutomationProxy.
- // This function is called from within UITest::SetUp().
- virtual ProxyLauncher* CreateProxyLauncher();
+ // This function is called from within UITest::LaunchBrowserAndServer.
+ virtual AutomationProxy* CreateAutomationProxy(int execution_timeout);
protected:
// Filtered Inet will override automation callbacks for network resources.
virtual bool ShouldFilterInet() {
return false;
}
ExternalTabUITestMockClient* mock_;
- std::string channel_id_; // Channel id of automation proxy.
};
#endif // CHROME_TEST_AUTOMATION_AUTOMATION_PROXY_UITEST_H_
« no previous file with comments | « chrome/test/automation/automation_proxy.cc ('k') | chrome/test/automation/automation_proxy_uitest.cc » ('j') | no next file with comments »
@@ -112,17 +112,16 @@ class ExternalTabUITestMockClient : public AutomationProxy {
public:
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {}
- // Override UITest's CreateProxyLauncher to provide the unit test
+ // Override UITest's CreateAutomationProxy to provide the unit test
// with our special implementation of AutomationProxy.

Powered by Google App Engine
This is Rietveld 408576698